# Set App Name
app_name = "Bert's Interactive Lesson Loader (BILL)"
gui_dirname = 'bill.gui'
default_terminal_address = 'ws://127.0.0.1:5000/'
terminal_check_timeout = 5
webengine_choices = [
  'gtk',
  'qt',
  'edgechromium',
  'edgehtml',
  'mshtml',
  'cef'
]
settings = {}